summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: d325942)
raw | patch | inline | side by side (parent: d325942)
author | Sebastian Harl <sh@tokkee.org> | |
Wed, 19 Nov 2014 23:13:41 +0000 (00:13 +0100) | ||
committer | Sebastian Harl <sh@tokkee.org> | |
Wed, 19 Nov 2014 23:13:41 +0000 (00:13 +0100) |
proto/proto.go | patch | blob | history |
diff --git a/proto/proto.go b/proto/proto.go
index 91e21122b82ac5013d7bc90bbbe933d7ade4dbd1..ee47fcfcf0442d78e4a89f076491bc629dc427da 100644 (file)
--- a/proto/proto.go
+++ b/proto/proto.go
// 'TIMESERIES' command in the server.
ConnectionTimeseries = Status(7)
- // ConnectionExpr is the internal state for expression parsing.
- ConnectionExpr = Status(100)
+ // ConnectionMatcher is the internal state for parsing matchers.
+ ConnectionMatcher = Status(100)
+ // ConnectionExpr is the internal state for parsing expressions.
+ ConnectionExpr = Status(101)
)
// The DataType describes the type of data in a ConnectionData message.